@@ -71,6 +71,7 @@ typedef struct {
 #ifdef HAVE_COMPOSITE
 	gboolean   ignore_composite;
 #endif /* HAVE_COMPOSITE */
+	gboolean  print_version;
 } MagnifierOptions;
 
 static MagnifierOptions global_options = { NULL,      /* target_display */
@@ -105,6 +106,7 @@ static MagnifierOptions global_options = { NULL,      /* target_display */
 #ifdef HAVE_COMPOSITE
 					   ,0         /* ignore_composite */
 #endif /* HAVE_COMPOSITE */
+					   ,0         /* print_version */
                                          };
 
 static GOptionEntry magnifier_options [] = {
@@ -138,6 +140,7 @@ static GOptionEntry magnifier_options [] = {
 #ifdef HAVE_COMPOSITE
 	{"ignore-composite", 0, 0, G_OPTION_ARG_NONE, &global_options.ignore_composite, "ignore the X server COMPOSITE extension, if present", NULL},
 #endif /* HAVE_COMPOSITE */
+	{"version", 'v', 0, G_OPTION_ARG_NONE, &global_options.print_version, "print version", NULL},
 	{NULL}
 };
 
@@ -375,6 +378,11 @@ main (int argc, char** argv)
   g_option_context_parse(context, &argc, &argv, NULL);
   g_option_context_free(context);
 
+  if (global_options.print_version) {
+	  g_print ("%s\n", VERSION);
+	  return 0;
+  }
+
   /** 
    * slight hack, we set $DISPLAY if --target-display is set.
    * this is because I don't think GTK+ works well with across multiple 
